package org.dromara.ems.info.service;

import org.dromara.ems.info.domain.LuggageSystemSecurityDoorBatteryLifecycle;

import java.util.List;

/**
 * 行李系统安全门铅酸电池生命周期Service接口
 * 
 * @author Yinq
 * @date 2025-06-05
 */
public interface ILuggageSystemSecurityDoorBatteryLifecycleService 
{
    /**
     * 查询行李系统安全门铅酸电池生命周期
     * 
     * @param objid 行李系统安全门铅酸电池生命周期主键
     * @return 行李系统安全门铅酸电池生命周期
     */
    public LuggageSystemSecurityDoorBatteryLifecycle selectLuggageSystemSecurityDoorBatteryLifecycleByObjid(Long objid);

    /**
     * 查询行李系统安全门铅酸电池生命周期列表
     * 
     * @param luggageSystemSecurityDoorBatteryLifecycle 行李系统安全门铅酸电池生命周期
     * @return 行李系统安全门铅酸电池生命周期集合
     */
    public List<LuggageSystemSecurityDoorBatteryLifecycle> selectLuggageSystemSecurityDoorBatteryLifecycleList(LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle);

    /**
     * 新增行李系统安全门铅酸电池生命周期
     * 
     * @param luggageSystemSecurityDoorBatteryLifecycle 行李系统安全门铅酸电池生命周期
     * @return 结果
     */
    public int insertLuggageSystemSecurityDoorBatteryLifecycle(LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle);

    /**
     * 修改行李系统安全门铅酸电池生命周期
     * 
     * @param luggageSystemSecurityDoorBatteryLifecycle 行李系统安全门铅酸电池生命周期
     * @return 结果
     */
    public int updateLuggageSystemSecurityDoorBatteryLifecycle(LuggageSystemSecurityDoorBatteryLifecycle luggageSystemSecurityDoorBatteryLifecycle);

    /**
     * 批量删除行李系统安全门铅酸电池生命周期
     * 
     * @param objids 需要删除的行李系统安全门铅酸电池生命周期主键集合
     * @return 结果
     */
    public int deleteLuggageSystemSecurityDoorBatteryLifecycleByObjids(Long[] objids);

    /**
     * 删除行李系统安全门铅酸电池生命周期信息
     * 
     * @param objid 行李系统安全门铅酸电池生命周期主键
     * @return 结果
     */
    public int deleteLuggageSystemSecurityDoorBatteryLifecycleByObjid(Long objid);

    /**
     * 导入行李系统安全门铅酸电池生命周期数据
     * 
     * @param dataList 行李系统安全门铅酸电池生命周期数据列表
     * @param updateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importLuggageSystemSecurityDoorBatteryLifecycle(List<LuggageSystemSecurityDoorBatteryLifecycle> dataList, Boolean updateSupport, String operName);
}
